… | OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
   1. 1 Commercial manned guarding
   2. Ω Riesgos añadidos (por Ud)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Sin respuesta
   - Pospuesto
   - OK
   - Atención
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

## Describir el riesgo…

¿Este riesgo es aceptable o bajo control? No, se requieren más medidas Sí, el riesgo residual es aceptable

Select the priority of this risk Low Medium High
Información
Subir una imagenlabel_upload_image
Comentarios

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More